# coding: utf-8

"""
    Coinbase Developer Platform APIs

    The Coinbase Developer Platform APIs - leading the world's transition onchain.

    The version of the OpenAPI document: 2.0.0
    Contact: cdp@coinbase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cdp.openapi_client.models.list_evm_accounts200_response import ListEvmAccounts200Response

class TestListEvmAccounts200Response(unittest.TestCase):
    """ListEvmAccounts200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListEvmAccounts200Response:
        """Test ListEvmAccounts200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListEvmAccounts200Response`
        """
        model = ListEvmAccounts200Response()
        if include_optional:
            return ListEvmAccounts200Response(
                next_page_token = 'eyJsYXN0X2lkIjogImFiYzEyMyIsICJ0aW1lc3RhbXAiOiAxNzA3ODIzNzAxfQ==',
                accounts = [
                    cdp.openapi_client.models.evm_account.EvmAccount(
                        address = '0x742d35Cc6634C0532925a3b844Bc454e4438f44e', 
                        name = 'my-account', 
                        policies = ["123e4567-e89b-12d3-a456-426614174000"], )
                    ]
            )
        else:
            return ListEvmAccounts200Response(
                accounts = [
                    cdp.openapi_client.models.evm_account.EvmAccount(
                        address = '0x742d35Cc6634C0532925a3b844Bc454e4438f44e', 
                        name = 'my-account', 
                        policies = ["123e4567-e89b-12d3-a456-426614174000"], )
                    ],
        )
        """

    def testListEvmAccounts200Response(self):
        """Test ListEvmAccounts200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
